# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.report.v1 import report_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2


class ReportServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListReports = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.report.v1.ReportService/ListReports',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.ListReportsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.ListReportsResponse.FromString,
                )
        self.CreateReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.report.v1.ReportService/CreateReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.CreateReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.CreateReportResponse.FromString,
                )
        self.GetReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.report.v1.ReportService/GetReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.GetReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.GetReportResponse.FromString,
                )
        self.UpdateReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.report.v1.ReportService/UpdateReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.UpdateReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.UpdateReportResponse.FromString,
                )
        self.DeleteReport = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.report.v1.ReportService/DeleteReport',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DeleteReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DeleteReportResponse.FromString,
                )
        self.Download = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.report.v1.ReportService/Download',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DownloadReportRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DownloadReportResponse.FromString,
                )


class ReportServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListReports(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteReport(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Download(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReportServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListReports': grpc.unary_unary_rpc_method_handler(
                    servicer.ListReports,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.ListReportsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.ListReportsResponse.SerializeToString,
            ),
            'CreateReport': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.CreateReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.CreateReportResponse.SerializeToString,
            ),
            'GetReport': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.GetReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.GetReportResponse.SerializeToString,
            ),
            'UpdateReport': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.UpdateReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.UpdateReportResponse.SerializeToString,
            ),
            'DeleteReport': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteReport,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DeleteReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DeleteReportResponse.SerializeToString,
            ),
            'Download': grpc.unary_unary_rpc_method_handler(
                    servicer.Download,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DownloadReportRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DownloadReportResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.report.v1.ReportService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ReportService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListReports(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.report.v1.ReportService/ListReports',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.ListReportsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.ListReportsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.report.v1.ReportService/CreateReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.CreateReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.CreateReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.report.v1.ReportService/GetReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.GetReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.GetReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.report.v1.ReportService/UpdateReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.UpdateReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.UpdateReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.report.v1.ReportService/DeleteReport',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DeleteReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DeleteReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.report.v1.ReportService/Download',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DownloadReportRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_report_dot_v1_dot_report__pb2.DownloadReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/notebookrun/v1/notebookrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGgithub.com/metaprov/modelaapi/services/notebookrun/v1/notebookrun.proto\x12\x35github.com.metaprov.modelaapi.services.notebookrun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\x80\x02\n\x17ListNotebookRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12j\n\x06labels\x18\x02 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x94\x01\n\x18ListNotebookRunsResponse\x12_\n\x0cnotebookruns\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x15\n\x13NotebookRunResponse\"v\n\x18\x43reateNotebookRunRequest\x12Z\n\x0bnotebookrun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x1b\n\x19\x43reateNotebookRunResponse\"\xa6\x01\n\x18UpdateNotebookRunRequest\x12Z\n\x0bnotebookrun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1b\n\x19UpdateNotebookRunResponse\"8\n\x15GetNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x81\x01\n\x16GetNotebookRunResponse\x12Y\n\nnotbookrun\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\";\n\x18\x44\x65leteNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1b\n\x19\x44\x65leteNotebookRunResponse2\x9c\t\n\x12NotebookRunService\x12\xd9\x01\n\x10ListNotebookRuns\x12N.github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest\x1aO.github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/notebookruns/{namespace}\x12\xd3\x01\n\x11\x43reateNotebookRun\x12O.github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunRequest\x1aP.github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/notebookruns:\x01*\x12\xda\x01\n\x0eGetNotebookRun\x12L.github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunRequest\x1aM.github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/notebookruns/{namespace}/{name}\x12\x90\x02\n\x11UpdateNotebookRun\x12O.github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunRequest\x1aP.github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunResponse\"X\x82\xd3\xe4\x93\x02R\x1aM/v1/notebookruns/{notebookrun.metadata.namespace}/{notebookrun.metadata.name}:\x01*\x12\xe3\x01\n\x11\x44\x65leteNotebookRun\x12O.github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunRequest\x1aP.github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunResponse\"+\x82\xd3\xe4\x93\x02%*#/v1/notebookruns/{namespace}/{name}B7Z5github.com/metaprov/modelaapi/services/notebookrun/v1b\x06proto3')



_LISTNOTEBOOKRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListNotebookRunsRequest']
_LISTNOTEBOOKRUNSREQUEST_LABELSENTRY = _LISTNOTEBOOKRUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTNOTEBOOKRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListNotebookRunsResponse']
_NOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['NotebookRunResponse']
_CREATENOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateNotebookRunRequest']
_CREATENOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateNotebookRunResponse']
_UPDATENOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateNotebookRunRequest']
_UPDATENOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateNotebookRunResponse']
_GETNOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['GetNotebookRunRequest']
_GETNOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['GetNotebookRunResponse']
_DELETENOTEBOOKRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteNotebookRunRequest']
_DELETENOTEBOOKRUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteNotebookRunResponse']
ListNotebookRunsRequest = _reflection.GeneratedProtocolMessageType('ListNotebookRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsRequest)
  })
_sym_db.RegisterMessage(ListNotebookRunsRequest)
_sym_db.RegisterMessage(ListNotebookRunsRequest.LabelsEntry)

ListNotebookRunsResponse = _reflection.GeneratedProtocolMessageType('ListNotebookRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.ListNotebookRunsResponse)
  })
_sym_db.RegisterMessage(ListNotebookRunsResponse)

NotebookRunResponse = _reflection.GeneratedProtocolMessageType('NotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunResponse)
  })
_sym_db.RegisterMessage(NotebookRunResponse)

CreateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRunRequest)

CreateNotebookRunResponse = _reflection.GeneratedProtocolMessageType('CreateNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.CreateNotebookRunResponse)
  })
_sym_db.RegisterMessage(CreateNotebookRunResponse)

UpdateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRunRequest)

UpdateNotebookRunResponse = _reflection.GeneratedProtocolMessageType('UpdateNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.UpdateNotebookRunResponse)
  })
_sym_db.RegisterMessage(UpdateNotebookRunResponse)

GetNotebookRunRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunRequest)
  })
_sym_db.RegisterMessage(GetNotebookRunRequest)

GetNotebookRunResponse = _reflection.GeneratedProtocolMessageType('GetNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.GetNotebookRunResponse)
  })
_sym_db.RegisterMessage(GetNotebookRunResponse)

DeleteNotebookRunRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRunRequest)

DeleteNotebookRunResponse = _reflection.GeneratedProtocolMessageType('DeleteNotebookRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.notebookrun.v1.notebookrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.notebookrun.v1.DeleteNotebookRunResponse)
  })
_sym_db.RegisterMessage(DeleteNotebookRunResponse)

_NOTEBOOKRUNSERVICE = DESCRIPTOR.services_by_name['NotebookRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/metaprov/modelaapi/services/notebookrun/v1'
  _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY._options = None
  _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKRUNSERVICE.methods_by_name['ListNotebookRuns']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['ListNotebookRuns']._serialized_options = b'\202\323\344\223\002\036\022\034/v1/notebookruns/{namespace}'
  _NOTEBOOKRUNSERVICE.methods_by_name['CreateNotebookRun']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['CreateNotebookRun']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/notebookruns:\001*'
  _NOTEBOOKRUNSERVICE.methods_by_name['GetNotebookRun']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['GetNotebookRun']._serialized_options = b'\202\323\344\223\002%\022#/v1/notebookruns/{namespace}/{name}'
  _NOTEBOOKRUNSERVICE.methods_by_name['UpdateNotebookRun']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['UpdateNotebookRun']._serialized_options = b'\202\323\344\223\002R\032M/v1/notebookruns/{notebookrun.metadata.namespace}/{notebookrun.metadata.name}:\001*'
  _NOTEBOOKRUNSERVICE.methods_by_name['DeleteNotebookRun']._options = None
  _NOTEBOOKRUNSERVICE.methods_by_name['DeleteNotebookRun']._serialized_options = b'\202\323\344\223\002%*#/v1/notebookruns/{namespace}/{name}'
  _LISTNOTEBOOKRUNSREQUEST._serialized_start=332
  _LISTNOTEBOOKRUNSREQUEST._serialized_end=588
  _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY._serialized_start=543
  _LISTNOTEBOOKRUNSREQUEST_LABELSENTRY._serialized_end=588
  _LISTNOTEBOOKRUNSRESPONSE._serialized_start=591
  _LISTNOTEBOOKRUNSRESPONSE._serialized_end=739
  _NOTEBOOKRUNRESPONSE._serialized_start=741
  _NOTEBOOKRUNRESPONSE._serialized_end=762
  _CREATENOTEBOOKRUNREQUEST._serialized_start=764
  _CREATENOTEBOOKRUNREQUEST._serialized_end=882
  _CREATENOTEBOOKRUNRESPONSE._serialized_start=884
  _CREATENOTEBOOKRUNRESPONSE._serialized_end=911
  _UPDATENOTEBOOKRUNREQUEST._serialized_start=914
  _UPDATENOTEBOOKRUNREQUEST._serialized_end=1080
  _UPDATENOTEBOOKRUNRESPONSE._serialized_start=1082
  _UPDATENOTEBOOKRUNRESPONSE._serialized_end=1109
  _GETNOTEBOOKRUNREQUEST._serialized_start=1111
  _GETNOTEBOOKRUNREQUEST._serialized_end=1167
  _GETNOTEBOOKRUNRESPONSE._serialized_start=1170
  _GETNOTEBOOKRUNRESPONSE._serialized_end=1299
  _DELETENOTEBOOKRUNREQUEST._serialized_start=1301
  _DELETENOTEBOOKRUNREQUEST._serialized_end=1360
  _DELETENOTEBOOKRUNRESPONSE._serialized_start=1362
  _DELETENOTEBOOKRUNRESPONSE._serialized_end=1389
  _NOTEBOOKRUNSERVICE._serialized_start=1392
  _NOTEBOOKRUNSERVICE._serialized_end=2572
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/postmortem/v1/postmortem.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/postmortem/v1/postmortem.proto\x12\x34github.com.metaprov.modelaapi.services.postmortem.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\"\xfd\x01\n\x16ListPostMortemsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x17ListPostMortemsResponse\x12Y\n\x0bpostmortems\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"o\n\x17\x43reatePostMortemRequest\x12T\n\npostmortem\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x1a\n\x18\x43reatePostMortemResponse\"\x9f\x01\n\x17UpdatePostMortemRequest\x12T\n\npostmortem\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdatePostMortemResponse\"7\n\x14GetPostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n\x15GetPostMortemResponse\x12T\n\npostmortem\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65letePostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65letePostMortemResponse2\xfb\x08\n\x11PostMortemService\x12\xd3\x01\n\x0fListPostMortems\x12L.github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest\x1aM.github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/postmortems/{namespace}\x12\xcd\x01\n\x10\x43reatePostMortem\x12M.github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest\x1aN.github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/postmortems:\x01*\x12\xd4\x01\n\rGetPostMortem\x12J.github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest\x1aK.github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/postmortems/{namespace}/{name}\x12\x88\x02\n\x10UpdatePostMortem\x12M.github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest\x1aN.github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/postmortems/{postmortem.metadata.namespace}/{postmortem.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65letePostMortem\x12M.github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest\x1aN.github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/postmortems/{namespace}/{name}B6Z4github.com/metaprov/modelaapi/services/postmortem/v1b\x06proto3')



_LISTPOSTMORTEMSREQUEST = DESCRIPTOR.message_types_by_name['ListPostMortemsRequest']
_LISTPOSTMORTEMSREQUEST_LABELSENTRY = _LISTPOSTMORTEMSREQUEST.nested_types_by_name['LabelsEntry']
_LISTPOSTMORTEMSRESPONSE = DESCRIPTOR.message_types_by_name['ListPostMortemsResponse']
_CREATEPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['CreatePostMortemRequest']
_CREATEPOSTMORTEMRESPONSE = DESCRIPTOR.message_types_by_name['CreatePostMortemResponse']
_UPDATEPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['UpdatePostMortemRequest']
_UPDATEPOSTMORTEMRESPONSE = DESCRIPTOR.message_types_by_name['UpdatePostMortemResponse']
_GETPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['GetPostMortemRequest']
_GETPOSTMORTEMRESPONSE = DESCRIPTOR.message_types_by_name['GetPostMortemResponse']
_DELETEPOSTMORTEMREQUEST = DESCRIPTOR.message_types_by_name['DeletePostMortemRequest']
_DELETEPOSTMORTEMRESPONSE = DESCRIPTOR.message_types_by_name['DeletePostMortemResponse']
ListPostMortemsRequest = _reflection.GeneratedProtocolMessageType('ListPostMortemsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPOSTMORTEMSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPOSTMORTEMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest)
  })
_sym_db.RegisterMessage(ListPostMortemsRequest)
_sym_db.RegisterMessage(ListPostMortemsRequest.LabelsEntry)

ListPostMortemsResponse = _reflection.GeneratedProtocolMessageType('ListPostMortemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOSTMORTEMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse)
  })
_sym_db.RegisterMessage(ListPostMortemsResponse)

CreatePostMortemRequest = _reflection.GeneratedProtocolMessageType('CreatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest)
  })
_sym_db.RegisterMessage(CreatePostMortemRequest)

CreatePostMortemResponse = _reflection.GeneratedProtocolMessageType('CreatePostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemResponse)
  })
_sym_db.RegisterMessage(CreatePostMortemResponse)

UpdatePostMortemRequest = _reflection.GeneratedProtocolMessageType('UpdatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest)
  })
_sym_db.RegisterMessage(UpdatePostMortemRequest)

UpdatePostMortemResponse = _reflection.GeneratedProtocolMessageType('UpdatePostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemResponse)
  })
_sym_db.RegisterMessage(UpdatePostMortemResponse)

GetPostMortemRequest = _reflection.GeneratedProtocolMessageType('GetPostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest)
  })
_sym_db.RegisterMessage(GetPostMortemRequest)

GetPostMortemResponse = _reflection.GeneratedProtocolMessageType('GetPostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse)
  })
_sym_db.RegisterMessage(GetPostMortemResponse)

DeletePostMortemRequest = _reflection.GeneratedProtocolMessageType('DeletePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest)
  })
_sym_db.RegisterMessage(DeletePostMortemRequest)

DeletePostMortemResponse = _reflection.GeneratedProtocolMessageType('DeletePostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemResponse)
  })
_sym_db.RegisterMessage(DeletePostMortemResponse)

_POSTMORTEMSERVICE = DESCRIPTOR.services_by_name['PostMortemService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/postmortem/v1'
  _LISTPOSTMORTEMSREQUEST_LABELSENTRY._options = None
  _LISTPOSTMORTEMSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _POSTMORTEMSERVICE.methods_by_name['ListPostMortems']._options = None
  _POSTMORTEMSERVICE.methods_by_name['ListPostMortems']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/postmortems/{namespace}'
  _POSTMORTEMSERVICE.methods_by_name['CreatePostMortem']._options = None
  _POSTMORTEMSERVICE.methods_by_name['CreatePostMortem']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/postmortems:\001*'
  _POSTMORTEMSERVICE.methods_by_name['GetPostMortem']._options = None
  _POSTMORTEMSERVICE.methods_by_name['GetPostMortem']._serialized_options = b'\202\323\344\223\002$\022\"/v1/postmortems/{namespace}/{name}'
  _POSTMORTEMSERVICE.methods_by_name['UpdatePostMortem']._options = None
  _POSTMORTEMSERVICE.methods_by_name['UpdatePostMortem']._serialized_options = b'\202\323\344\223\002O\032J/v1/postmortems/{postmortem.metadata.namespace}/{postmortem.metadata.name}:\001*'
  _POSTMORTEMSERVICE.methods_by_name['DeletePostMortem']._options = None
  _POSTMORTEMSERVICE.methods_by_name['DeletePostMortem']._serialized_options = b'\202\323\344\223\002$*\"/v1/postmortems/{namespace}/{name}'
  _LISTPOSTMORTEMSREQUEST._serialized_start=262
  _LISTPOSTMORTEMSREQUEST._serialized_end=515
  _LISTPOSTMORTEMSREQUEST_LABELSENTRY._serialized_start=470
  _LISTPOSTMORTEMSREQUEST_LABELSENTRY._serialized_end=515
  _LISTPOSTMORTEMSRESPONSE._serialized_start=518
  _LISTPOSTMORTEMSRESPONSE._serialized_end=659
  _CREATEPOSTMORTEMREQUEST._serialized_start=661
  _CREATEPOSTMORTEMREQUEST._serialized_end=772
  _CREATEPOSTMORTEMRESPONSE._serialized_start=774
  _CREATEPOSTMORTEMRESPONSE._serialized_end=800
  _UPDATEPOSTMORTEMREQUEST._serialized_start=803
  _UPDATEPOSTMORTEMREQUEST._serialized_end=962
  _UPDATEPOSTMORTEMRESPONSE._serialized_start=964
  _UPDATEPOSTMORTEMRESPONSE._serialized_end=990
  _GETPOSTMORTEMREQUEST._serialized_start=992
  _GETPOSTMORTEMREQUEST._serialized_end=1047
  _GETPOSTMORTEMRESPONSE._serialized_start=1049
  _GETPOSTMORTEMRESPONSE._serialized_end=1172
  _DELETEPOSTMORTEMREQUEST._serialized_start=1174
  _DELETEPOSTMORTEMREQUEST._serialized_end=1232
  _DELETEPOSTMORTEMRESPONSE._serialized_start=1234
  _DELETEPOSTMORTEMRESPONSE._serialized_end=1260
  _POSTMORTEMSERVICE._serialized_start=1263
  _POSTMORTEMSERVICE._serialized_end=2410
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/featurepipelinerun/v1/featurepipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nUgithub.com/metaprov/modelaapi/services/featurepipelinerun/v1/featurepipelinerun.proto\x12<github.com.metaprov.modelaapi.services.featurepipelinerun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x93\x02\n\x1dListFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12w\n\x06labels\x18\x02 \x03(\x0b\x32g.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa4\x01\n\x1eListFeaturePipelineRunResponse\x12i\n\x13\x66\x65\x61turepipelineruns\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x87\x01\n\x1f\x43reateFeaturePipelineRunRequest\x12\x64\n\x12\x66\x65\x61turepipelinerun\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\"\n CreateFeaturePipelineRunResponse\"\xb7\x01\n\x1fUpdateFeaturePipelineRunRequest\x12\x64\n\x12\x66\x65\x61turepipelinerun\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\"\n UpdateFeaturePipelineRunResponse\"?\n\x1cGetFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x93\x01\n\x1dGetFeaturePipelineRunResponse\x12\x64\n\x12\x66\x65\x61turepipelinerun\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"B\n\x1f\x44\x65leteFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\"\n DeleteFeaturePipelineRunResponse2\xfa\n\n\x19\x46\x65\x61turePipelineRunService\x12\x81\x02\n\x17ListFeaturePipelineRuns\x12[.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest\x1a\\.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunResponse\"+\x82\xd3\xe4\x93\x02%\x12#/v1/featurepipelineruns/{namespace}\x12\xfd\x01\n\x18\x43reateFeaturePipelineRun\x12].github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/featurepipelineruns:\x01*\x12\x84\x02\n\x15GetFeaturePipelineRun\x12Z.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunRequest\x1a[.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunResponse\"2\x82\xd3\xe4\x93\x02,\x12*/v1/featurepipelineruns/{namespace}/{name}\x12\xc5\x02\n\x18UpdateFeaturePipelineRun\x12].github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunResponse\"j\x82\xd3\xe4\x93\x02\x64\x1a_/v1/featurepipelines/{featurepipelinerun.metadata.namespace}/{featurepipelinerun.metadata.name}:\x01*\x12\x89\x02\n\x18\x44\x65leteFeaturePipelineRun\x12].github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunResponse\".\x82\xd3\xe4\x93\x02(*&/v1/featurepipeline/{namespace}/{name}B>Z<github.com/metaprov/modelaapi/services/featurepipelinerun/v1b\x06proto3')



_LISTFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunRequest']
_LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY = _LISTFEATUREPIPELINERUNREQUEST.nested_types_by_name['LabelsEntry']
_LISTFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunResponse']
_CREATEFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRunRequest']
_CREATEFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRunResponse']
_UPDATEFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRunRequest']
_UPDATEFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRunResponse']
_GETFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetFeaturePipelineRunRequest']
_GETFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['GetFeaturePipelineRunResponse']
_DELETEFEATUREPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRunRequest']
_DELETEFEATUREPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRunResponse']
ListFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunRequest)
_sym_db.RegisterMessage(ListFeaturePipelineRunRequest.LabelsEntry)

ListFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.ListFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunResponse)

CreateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRunRequest)

CreateFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.CreateFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRunResponse)

UpdateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRunRequest)

UpdateFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.UpdateFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRunResponse)

GetFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRunRequest)

GetFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.GetFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRunResponse)

DeleteFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRunRequest)

DeleteFeaturePipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.featurepipelinerun.v1.featurepipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.featurepipelinerun.v1.DeleteFeaturePipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRunResponse)

_FEATUREPIPELINERUNSERVICE = DESCRIPTOR.services_by_name['FeaturePipelineRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z<github.com/metaprov/modelaapi/services/featurepipelinerun/v1'
  _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY._options = None
  _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['ListFeaturePipelineRuns']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['ListFeaturePipelineRuns']._serialized_options = b'\202\323\344\223\002%\022#/v1/featurepipelineruns/{namespace}'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['CreateFeaturePipelineRun']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['CreateFeaturePipelineRun']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/featurepipelineruns:\001*'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['GetFeaturePipelineRun']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['GetFeaturePipelineRun']._serialized_options = b'\202\323\344\223\002,\022*/v1/featurepipelineruns/{namespace}/{name}'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['UpdateFeaturePipelineRun']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['UpdateFeaturePipelineRun']._serialized_options = b'\202\323\344\223\002d\032_/v1/featurepipelines/{featurepipelinerun.metadata.namespace}/{featurepipelinerun.metadata.name}:\001*'
  _FEATUREPIPELINERUNSERVICE.methods_by_name['DeleteFeaturePipelineRun']._options = None
  _FEATUREPIPELINERUNSERVICE.methods_by_name['DeleteFeaturePipelineRun']._serialized_options = b'\202\323\344\223\002(*&/v1/featurepipeline/{namespace}/{name}'
  _LISTFEATUREPIPELINERUNREQUEST._serialized_start=286
  _LISTFEATUREPIPELINERUNREQUEST._serialized_end=561
  _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY._serialized_start=516
  _LISTFEATUREPIPELINERUNREQUEST_LABELSENTRY._serialized_end=561
  _LISTFEATUREPIPELINERUNRESPONSE._serialized_start=564
  _LISTFEATUREPIPELINERUNRESPONSE._serialized_end=728
  _CREATEFEATUREPIPELINERUNREQUEST._serialized_start=731
  _CREATEFEATUREPIPELINERUNREQUEST._serialized_end=866
  _CREATEFEATUREPIPELINERUNRESPONSE._serialized_start=868
  _CREATEFEATUREPIPELINERUNRESPONSE._serialized_end=902
  _UPDATEFEATUREPIPELINERUNREQUEST._serialized_start=905
  _UPDATEFEATUREPIPELINERUNREQUEST._serialized_end=1088
  _UPDATEFEATUREPIPELINERUNRESPONSE._serialized_start=1090
  _UPDATEFEATUREPIPELINERUNRESPONSE._serialized_end=1124
  _GETFEATUREPIPELINERUNREQUEST._serialized_start=1126
  _GETFEATUREPIPELINERUNREQUEST._serialized_end=1189
  _GETFEATUREPIPELINERUNRESPONSE._serialized_start=1192
  _GETFEATUREPIPELINERUNRESPONSE._serialized_end=1339
  _DELETEFEATUREPIPELINERUNREQUEST._serialized_start=1341
  _DELETEFEATUREPIPELINERUNREQUEST._serialized_end=1407
  _DELETEFEATUREPIPELINERUNRESPONSE._serialized_start=1409
  _DELETEFEATUREPIPELINERUNRESPONSE._serialized_end=1443
  _FEATUREPIPELINERUNSERVICE._serialized_start=1446
  _FEATUREPIPELINERUNSERVICE._serialized_end=2848
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.reciperun.v1 import reciperun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2


class RecipeRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListRecipeRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/ListRecipeRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.ListRecipeRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.ListRecipeRunsResponse.FromString,
                )
        self.CreateRecipeRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/CreateRecipeRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.CreateRecipeRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.CreateRecipeRunResponse.FromString,
                )
        self.GetRecipeRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/GetRecipeRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.GetRecipeRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.GetRecipeRunResponse.FromString,
                )
        self.UpdateRecipeRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/UpdateRecipeRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.UpdateRecipeRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.UpdateRecipeRunResponse.FromString,
                )
        self.DeleteRecipeRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/DeleteRecipeRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.DeleteRecipeRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.DeleteRecipeRunResponse.FromString,
                )


class RecipeRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListRecipeRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRecipeRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecipeRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRecipeRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteRecipeRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RecipeRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListRecipeRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRecipeRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.ListRecipeRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.ListRecipeRunsResponse.SerializeToString,
            ),
            'CreateRecipeRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRecipeRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.CreateRecipeRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.CreateRecipeRunResponse.SerializeToString,
            ),
            'GetRecipeRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecipeRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.GetRecipeRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.GetRecipeRunResponse.SerializeToString,
            ),
            'UpdateRecipeRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRecipeRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.UpdateRecipeRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.UpdateRecipeRunResponse.SerializeToString,
            ),
            'DeleteRecipeRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteRecipeRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.DeleteRecipeRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.DeleteRecipeRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RecipeRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListRecipeRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/ListRecipeRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.ListRecipeRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.ListRecipeRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateRecipeRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/CreateRecipeRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.CreateRecipeRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.CreateRecipeRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecipeRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/GetRecipeRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.GetRecipeRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.GetRecipeRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateRecipeRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/UpdateRecipeRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.UpdateRecipeRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.UpdateRecipeRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteRecipeRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.reciperun.v1.RecipeRunService/DeleteRecipeRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.DeleteRecipeRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_reciperun_dot_v1_dot_reciperun__pb2.DeleteRecipeRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/connection/v1/connection.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/connection/v1/connection.proto\x12\x34github.com.metaprov.modelaapi.services.connection.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"\xfd\x01\n\x16ListConnectionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8e\x01\n\x17ListConnectionsResponse\x12Z\n\x0b\x63onnections\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ConnectionList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8a\x02\n\x17\x43reateConnectionRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12i\n\x06secret\x18\x05 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1a\n\x18\x43reateConnectionResponse\"\xba\x02\n\x17UpdateConnectionRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12i\n\x06secret\x18\x02 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest.SecretEntry\x12.\n\nfield_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1a\n\x18UpdateConnectionResponse\"7\n\x14GetConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"|\n\x15GetConnectionResponse\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteConnectionResponse\"8\n\x15TestConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"5\n\x16TestConnectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xe2\n\n\x11\x43onnectionService\x12\xd3\x01\n\x0fListConnections\x12L.github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest\x1aM.github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/connections/{namespace}\x12\xcd\x01\n\x10\x43reateConnection\x12M.github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest\x1aN.github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/connections:\x01*\x12\xd4\x01\n\rGetConnection\x12J.github.com.metaprov.modelaapi.services.connection.v1.GetConnectionRequest\x1aK.github.com.metaprov.modelaapi.services.connection.v1.GetConnectionResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/connections/{namespace}/{name}\x12\x88\x02\n\x10UpdateConnection\x12M.github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest\x1aN.github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/connections/{connection.metadata.namespace}/{connection.metadata.name}:\x01*\x12\xe1\x01\n\x10\x44\x65leteConnection\x12M.github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionRequest\x1aN.github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionResponse\".\x82\xd3\xe4\x93\x02(*&/api/v1/connections/{namespace}/{name}\x12\xe0\x01\n\x0eTestConnection\x12K.github.com.metaprov.modelaapi.services.connection.v1.TestConnectionRequest\x1aL.github.com.metaprov.modelaapi.services.connection.v1.TestConnectionResponse\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/connections/{namespace}/{name}:testB6Z4github.com/metaprov/modelaapi/services/connection/v1b\x06proto3')



_LISTCONNECTIONSREQUEST = DESCRIPTOR.message_types_by_name['ListConnectionsRequest']
_LISTCONNECTIONSREQUEST_LABELSENTRY = _LISTCONNECTIONSREQUEST.nested_types_by_name['LabelsEntry']
_LISTCONNECTIONSRESPONSE = DESCRIPTOR.message_types_by_name['ListConnectionsResponse']
_CREATECONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['CreateConnectionRequest']
_CREATECONNECTIONREQUEST_SECRETENTRY = _CREATECONNECTIONREQUEST.nested_types_by_name['SecretEntry']
_CREATECONNECTIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateConnectionResponse']
_UPDATECONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateConnectionRequest']
_UPDATECONNECTIONREQUEST_SECRETENTRY = _UPDATECONNECTIONREQUEST.nested_types_by_name['SecretEntry']
_UPDATECONNECTIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdateConnectionResponse']
_GETCONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['GetConnectionRequest']
_GETCONNECTIONRESPONSE = DESCRIPTOR.message_types_by_name['GetConnectionResponse']
_DELETECONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteConnectionRequest']
_DELETECONNECTIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteConnectionResponse']
_TESTCONNECTIONREQUEST = DESCRIPTOR.message_types_by_name['TestConnectionRequest']
_TESTCONNECTIONRESPONSE = DESCRIPTOR.message_types_by_name['TestConnectionResponse']
ListConnectionsRequest = _reflection.GeneratedProtocolMessageType('ListConnectionsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCONNECTIONSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCONNECTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsRequest)
  })
_sym_db.RegisterMessage(ListConnectionsRequest)
_sym_db.RegisterMessage(ListConnectionsRequest.LabelsEntry)

ListConnectionsResponse = _reflection.GeneratedProtocolMessageType('ListConnectionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.ListConnectionsResponse)
  })
_sym_db.RegisterMessage(ListConnectionsResponse)

CreateConnectionRequest = _reflection.GeneratedProtocolMessageType('CreateConnectionRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATECONNECTIONREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionRequest)
  })
_sym_db.RegisterMessage(CreateConnectionRequest)
_sym_db.RegisterMessage(CreateConnectionRequest.SecretEntry)

CreateConnectionResponse = _reflection.GeneratedProtocolMessageType('CreateConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.CreateConnectionResponse)
  })
_sym_db.RegisterMessage(CreateConnectionResponse)

UpdateConnectionRequest = _reflection.GeneratedProtocolMessageType('UpdateConnectionRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATECONNECTIONREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionRequest)
  })
_sym_db.RegisterMessage(UpdateConnectionRequest)
_sym_db.RegisterMessage(UpdateConnectionRequest.SecretEntry)

UpdateConnectionResponse = _reflection.GeneratedProtocolMessageType('UpdateConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.UpdateConnectionResponse)
  })
_sym_db.RegisterMessage(UpdateConnectionResponse)

GetConnectionRequest = _reflection.GeneratedProtocolMessageType('GetConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.GetConnectionRequest)
  })
_sym_db.RegisterMessage(GetConnectionRequest)

GetConnectionResponse = _reflection.GeneratedProtocolMessageType('GetConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.GetConnectionResponse)
  })
_sym_db.RegisterMessage(GetConnectionResponse)

DeleteConnectionRequest = _reflection.GeneratedProtocolMessageType('DeleteConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionRequest)
  })
_sym_db.RegisterMessage(DeleteConnectionRequest)

DeleteConnectionResponse = _reflection.GeneratedProtocolMessageType('DeleteConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.DeleteConnectionResponse)
  })
_sym_db.RegisterMessage(DeleteConnectionResponse)

TestConnectionRequest = _reflection.GeneratedProtocolMessageType('TestConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.TestConnectionRequest)
  })
_sym_db.RegisterMessage(TestConnectionRequest)

TestConnectionResponse = _reflection.GeneratedProtocolMessageType('TestConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTCONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.connection.v1.connection_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.connection.v1.TestConnectionResponse)
  })
_sym_db.RegisterMessage(TestConnectionResponse)

_CONNECTIONSERVICE = DESCRIPTOR.services_by_name['ConnectionService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/connection/v1'
  _LISTCONNECTIONSREQUEST_LABELSENTRY._options = None
  _LISTCONNECTIONSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECONNECTIONREQUEST_SECRETENTRY._options = None
  _CREATECONNECTIONREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _UPDATECONNECTIONREQUEST_SECRETENTRY._options = None
  _UPDATECONNECTIONREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CONNECTIONSERVICE.methods_by_name['ListConnections']._options = None
  _CONNECTIONSERVICE.methods_by_name['ListConnections']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/connections/{namespace}'
  _CONNECTIONSERVICE.methods_by_name['CreateConnection']._options = None
  _CONNECTIONSERVICE.methods_by_name['CreateConnection']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/connections:\001*'
  _CONNECTIONSERVICE.methods_by_name['GetConnection']._options = None
  _CONNECTIONSERVICE.methods_by_name['GetConnection']._serialized_options = b'\202\323\344\223\002$\022\"/v1/connections/{namespace}/{name}'
  _CONNECTIONSERVICE.methods_by_name['UpdateConnection']._options = None
  _CONNECTIONSERVICE.methods_by_name['UpdateConnection']._serialized_options = b'\202\323\344\223\002O\032J/v1/connections/{connection.metadata.namespace}/{connection.metadata.name}:\001*'
  _CONNECTIONSERVICE.methods_by_name['DeleteConnection']._options = None
  _CONNECTIONSERVICE.methods_by_name['DeleteConnection']._serialized_options = b'\202\323\344\223\002(*&/api/v1/connections/{namespace}/{name}'
  _CONNECTIONSERVICE.methods_by_name['TestConnection']._options = None
  _CONNECTIONSERVICE.methods_by_name['TestConnection']._serialized_options = b'\202\323\344\223\002-\022+/api/v1/connections/{namespace}/{name}:test'
  _LISTCONNECTIONSREQUEST._serialized_start=263
  _LISTCONNECTIONSREQUEST._serialized_end=516
  _LISTCONNECTIONSREQUEST_LABELSENTRY._serialized_start=471
  _LISTCONNECTIONSREQUEST_LABELSENTRY._serialized_end=516
  _LISTCONNECTIONSRESPONSE._serialized_start=519
  _LISTCONNECTIONSRESPONSE._serialized_end=661
  _CREATECONNECTIONREQUEST._serialized_start=664
  _CREATECONNECTIONREQUEST._serialized_end=930
  _CREATECONNECTIONREQUEST_SECRETENTRY._serialized_start=885
  _CREATECONNECTIONREQUEST_SECRETENTRY._serialized_end=930
  _CREATECONNECTIONRESPONSE._serialized_start=932
  _CREATECONNECTIONRESPONSE._serialized_end=958
  _UPDATECONNECTIONREQUEST._serialized_start=961
  _UPDATECONNECTIONREQUEST._serialized_end=1275
  _UPDATECONNECTIONREQUEST_SECRETENTRY._serialized_start=885
  _UPDATECONNECTIONREQUEST_SECRETENTRY._serialized_end=930
  _UPDATECONNECTIONRESPONSE._serialized_start=1277
  _UPDATECONNECTIONRESPONSE._serialized_end=1303
  _GETCONNECTIONREQUEST._serialized_start=1305
  _GETCONNECTIONREQUEST._serialized_end=1360
  _GETCONNECTIONRESPONSE._serialized_start=1362
  _GETCONNECTIONRESPONSE._serialized_end=1486
  _DELETECONNECTIONREQUEST._serialized_start=1488
  _DELETECONNECTIONREQUEST._serialized_end=1546
  _DELETECONNECTIONRESPONSE._serialized_start=1548
  _DELETECONNECTIONRESPONSE._serialized_end=1574
  _TESTCONNECTIONREQUEST._serialized_start=1576
  _TESTCONNECTIONREQUEST._serialized_end=1632
  _TESTCONNECTIONRESPONSE._serialized_start=1634
  _TESTCONNECTIONRESPONSE._serialized_end=1687
  _CONNECTIONSERVICE._serialized_start=1690
  _CONNECTIONSERVICE._serialized_end=3068
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.notebookrun.v1 import notebookrun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2


class NotebookRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListNotebookRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/ListNotebookRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsResponse.FromString,
                )
        self.CreateNotebookRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/CreateNotebookRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunResponse.FromString,
                )
        self.GetNotebookRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/GetNotebookRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunResponse.FromString,
                )
        self.UpdateNotebookRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/UpdateNotebookRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunResponse.FromString,
                )
        self.DeleteNotebookRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/DeleteNotebookRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunResponse.FromString,
                )


class NotebookRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListNotebookRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNotebookRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotebookRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNotebookRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNotebookRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotebookRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListNotebookRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNotebookRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsResponse.SerializeToString,
            ),
            'CreateNotebookRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNotebookRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunResponse.SerializeToString,
            ),
            'GetNotebookRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotebookRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunResponse.SerializeToString,
            ),
            'UpdateNotebookRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNotebookRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunResponse.SerializeToString,
            ),
            'DeleteNotebookRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNotebookRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NotebookRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListNotebookRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/ListNotebookRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.ListNotebookRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNotebookRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/CreateNotebookRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.CreateNotebookRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotebookRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/GetNotebookRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.GetNotebookRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNotebookRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/UpdateNotebookRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.UpdateNotebookRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNotebookRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notebookrun.v1.NotebookRunService/DeleteNotebookRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notebookrun_dot_v1_dot_notebookrun__pb2.DeleteNotebookRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/webrequestrun/v1/webrequestrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKgithub.com/metaprov/modelaapi/services/webrequestrun/v1/webrequestrun.proto\x12\x37github.com.metaprov.modelaapi.services.webrequestrun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xdb\x01\n\x19ListWebRequestRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12n\n\x06labels\x18\x03 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x01\n\x1aListWebRequestRunsResponse\x12_\n\x0ewebrequestruns\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1d\n\x1b\x43reateWebRequestRunResponse\"x\n\x1a\x43reateWebRequestRunRequest\x12Z\n\rwebrequestrun\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\"\xa8\x01\n\x1aUpdateWebRequestRunRequest\x12Z\n\rwebrequestrun\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1d\n\x1bUpdateWebRequestRunResponse\":\n\x17GetWebRequestRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x84\x01\n\x18GetWebRequestRunResponse\x12Z\n\rwebrequestrun\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteWebRequestRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteWebRequestRunResponse2\xd2\t\n\x14WebRequestRunService\x12\xe5\x01\n\x12ListWebRequestRuns\x12R.github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest\x1aS.github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/webrequestruns/{namespace}\x12\xdf\x01\n\x13\x43reateWebRequestRun\x12S.github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunRequest\x1aT.github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/webrequestruns:\x01*\x12\xda\x01\n\x10GetWebRequestRun\x12P.github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunRequest\x1aQ.github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/webrequestruns/{name}\x12\xa0\x02\n\x13UpdateWebRequestRun\x12S.github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunRequest\x1aT.github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunResponse\"^\x82\xd3\xe4\x93\x02X\x1aS/v1/webrequestruns/{webrequestrun.metadata.namespace}/{webrequestrun.metadata.name}:\x01*\x12\xef\x01\n\x13\x44\x65leteWebRequestRun\x12S.github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunRequest\x1aT.github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunResponse\"-\x82\xd3\xe4\x93\x02\'*%/v1/webrequestruns/{namespace}/{name}B9Z7github.com/metaprov/modelaapi/services/webrequestrun/v1b\x06proto3')



_LISTWEBREQUESTRUNSREQUEST = DESCRIPTOR.message_types_by_name['ListWebRequestRunsRequest']
_LISTWEBREQUESTRUNSREQUEST_LABELSENTRY = _LISTWEBREQUESTRUNSREQUEST.nested_types_by_name['LabelsEntry']
_LISTWEBREQUESTRUNSRESPONSE = DESCRIPTOR.message_types_by_name['ListWebRequestRunsResponse']
_CREATEWEBREQUESTRUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateWebRequestRunResponse']
_CREATEWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['CreateWebRequestRunRequest']
_UPDATEWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateWebRequestRunRequest']
_UPDATEWEBREQUESTRUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateWebRequestRunResponse']
_GETWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['GetWebRequestRunRequest']
_GETWEBREQUESTRUNRESPONSE = DESCRIPTOR.message_types_by_name['GetWebRequestRunResponse']
_DELETEWEBREQUESTRUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteWebRequestRunRequest']
_DELETEWEBREQUESTRUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteWebRequestRunResponse']
ListWebRequestRunsRequest = _reflection.GeneratedProtocolMessageType('ListWebRequestRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTWEBREQUESTRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsRequest)
  })
_sym_db.RegisterMessage(ListWebRequestRunsRequest)
_sym_db.RegisterMessage(ListWebRequestRunsRequest.LabelsEntry)

ListWebRequestRunsResponse = _reflection.GeneratedProtocolMessageType('ListWebRequestRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.ListWebRequestRunsResponse)
  })
_sym_db.RegisterMessage(ListWebRequestRunsResponse)

CreateWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('CreateWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunResponse)
  })
_sym_db.RegisterMessage(CreateWebRequestRunResponse)

CreateWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('CreateWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.CreateWebRequestRunRequest)
  })
_sym_db.RegisterMessage(CreateWebRequestRunRequest)

UpdateWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunRequest)
  })
_sym_db.RegisterMessage(UpdateWebRequestRunRequest)

UpdateWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.UpdateWebRequestRunResponse)
  })
_sym_db.RegisterMessage(UpdateWebRequestRunResponse)

GetWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('GetWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunRequest)
  })
_sym_db.RegisterMessage(GetWebRequestRunRequest)

GetWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('GetWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.GetWebRequestRunResponse)
  })
_sym_db.RegisterMessage(GetWebRequestRunResponse)

DeleteWebRequestRunRequest = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunRequest)
  })
_sym_db.RegisterMessage(DeleteWebRequestRunRequest)

DeleteWebRequestRunResponse = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequestrun.v1.webrequestrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequestrun.v1.DeleteWebRequestRunResponse)
  })
_sym_db.RegisterMessage(DeleteWebRequestRunResponse)

_WEBREQUESTRUNSERVICE = DESCRIPTOR.services_by_name['WebRequestRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z7github.com/metaprov/modelaapi/services/webrequestrun/v1'
  _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY._options = None
  _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _WEBREQUESTRUNSERVICE.methods_by_name['ListWebRequestRuns']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['ListWebRequestRuns']._serialized_options = b'\202\323\344\223\002 \022\036/v1/webrequestruns/{namespace}'
  _WEBREQUESTRUNSERVICE.methods_by_name['CreateWebRequestRun']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['CreateWebRequestRun']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/webrequestruns:\001*'
  _WEBREQUESTRUNSERVICE.methods_by_name['GetWebRequestRun']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['GetWebRequestRun']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/webrequestruns/{name}'
  _WEBREQUESTRUNSERVICE.methods_by_name['UpdateWebRequestRun']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['UpdateWebRequestRun']._serialized_options = b'\202\323\344\223\002X\032S/v1/webrequestruns/{webrequestrun.metadata.namespace}/{webrequestrun.metadata.name}:\001*'
  _WEBREQUESTRUNSERVICE.methods_by_name['DeleteWebRequestRun']._options = None
  _WEBREQUESTRUNSERVICE.methods_by_name['DeleteWebRequestRun']._serialized_options = b'\202\323\344\223\002\'*%/v1/webrequestruns/{namespace}/{name}'
  _LISTWEBREQUESTRUNSREQUEST._serialized_start=271
  _LISTWEBREQUESTRUNSREQUEST._serialized_end=490
  _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY._serialized_start=445
  _LISTWEBREQUESTRUNSREQUEST_LABELSENTRY._serialized_end=490
  _LISTWEBREQUESTRUNSRESPONSE._serialized_start=493
  _LISTWEBREQUESTRUNSRESPONSE._serialized_end=643
  _CREATEWEBREQUESTRUNRESPONSE._serialized_start=645
  _CREATEWEBREQUESTRUNRESPONSE._serialized_end=674
  _CREATEWEBREQUESTRUNREQUEST._serialized_start=676
  _CREATEWEBREQUESTRUNREQUEST._serialized_end=796
  _UPDATEWEBREQUESTRUNREQUEST._serialized_start=799
  _UPDATEWEBREQUESTRUNREQUEST._serialized_end=967
  _UPDATEWEBREQUESTRUNRESPONSE._serialized_start=969
  _UPDATEWEBREQUESTRUNRESPONSE._serialized_end=998
  _GETWEBREQUESTRUNREQUEST._serialized_start=1000
  _GETWEBREQUESTRUNREQUEST._serialized_end=1058
  _GETWEBREQUESTRUNRESPONSE._serialized_start=1061
  _GETWEBREQUESTRUNRESPONSE._serialized_end=1193
  _DELETEWEBREQUESTRUNREQUEST._serialized_start=1195
  _DELETEWEBREQUESTRUNREQUEST._serialized_end=1256
  _DELETEWEBREQUESTRUNRESPONSE._serialized_start=1258
  _DELETEWEBREQUESTRUNRESPONSE._serialized_end=1287
  _WEBREQUESTRUNSERVICE._serialized_start=1290
  _WEBREQUESTRUNSERVICE._serialized_end=2524
# @@protoc_insertion_point(module_scope)
